@@ -60,13 +60,13 @@ static void opd_sigterm(void);
  */
 static void op_open_files(void)
 {
-	hashmapdevfd = op_open_device(OP_HASH_DEVICE);
+	hashmapdevfd = op_open_device(op_hash_device);
 	if (hashmapdevfd == -1) {
 		perror("Failed to open hash map device");
 		exit(EXIT_FAILURE);
 	}
 
-	notedevfd = op_open_device(OP_NOTE_DEVICE);
+	notedevfd = op_open_device(op_note_device);
 	if (notedevfd == -1) {
 		if (errno == EINVAL)
 			fprintf(stderr, "Failed to open note device. Possibly you have passed incorrect\n"
@@ -76,7 +76,7 @@ static void op_open_files(void)
 		exit(EXIT_FAILURE);
 	}
 
-	devfd = op_open_device(OP_DEVICE);
+	devfd = op_open_device(op_device);
 	if (devfd == -1) {
 		if (errno == EINVAL)
 			fprintf(stderr, "Failed to open device. Possibly you have passed incorrect\n"
@@ -89,7 +89,7 @@ static void op_open_files(void)
 	opd_init_hash_map();
 
 	/* give output before re-opening stdout as the logfile */
-	printf("Using log file " OP_LOG_FILE "\n");
+	printf("Using log file %s\n", op_log_file);
 
 	/* set up logfile */
 	close(0);
@@ -130,13 +130,11 @@ static void opd_shutdown(struct op_buffer_head * buf, size_t size, struct op_not
 	}
 
 	/* it's always OK to read the note device */
-	while (ncount < 0) {
+	while (ncount < 0)
 		ncount = op_read_device(notedevfd, nbuf, nsize);
-	}
 
-	if (ncount > 0) {
+	if (ncount > 0)
 		opd_do_notes(nbuf, ncount);
-	}
 
 	/* read as much as we can until we have exhausted the data
 	 * (EAGAIN is returned).
@@ -171,14 +169,11 @@ static void opd_do_read(struct op_buffer_head * buf, size_t size, struct op_note
 		ssize_t ncount = -1;
 
 		/* loop to handle EINTR */
-		while (count < 0) {
+		while (count < 0)
 			count = op_read_device(devfd, buf, size);
 
-		}
-
-		while (ncount < 0) {
+		while (ncount < 0)
 			ncount = op_read_device(notedevfd, nbuf, nsize);
-		}
 
 		opd_do_notes(nbuf, ncount);
 		opd_do_samples(buf);
@@ -295,7 +290,7 @@ static void opd_alarm(void)
 
 	opd_print_24_stats();
 
-	alarm(60*10);
+	alarm(60 * 10);
 }
  
 
@@ -315,7 +310,7 @@ static void clean_exit(void)
 {
 	opd_cleanup_hash_name();
 	op_free_events();
-	unlink(OP_LOCK_FILE);
+	unlink(op_lock_file);
 }
 
 
