@@ -55,8 +55,17 @@ protected:
 
 
 /** the popt array singleton options */
-static vector<poptOption> popt_options;
-static vector<option_base *> options_list;
+static vector<poptOption> & popt_options(void)
+{
+	static vector<poptOption> *x = new(vector<poptOption>);
+	return *x;
+}
+
+static vector<option_base *> & options_list(void)
+{
+	static vector<option_base *> *x = new(vector<option_base *>);
+	return *x;
+}
 
 static int showvers;
 
@@ -73,7 +82,7 @@ static poptContext do_parse_options(int argc, char const ** argv,
                                     vector<poptOption> & options,
                                     vector<string> & additional_params)
 {
-	options = popt_options;
+	options = popt_options();
 
 	int const nr_appended_options =
 		sizeof(appended_options) / sizeof(appended_options[0]);
@@ -83,18 +92,15 @@ static poptContext do_parse_options(int argc, char const ** argv,
 
 	poptContext con = op_poptGetContext(NULL, argc, argv, &options[0], 0);
 
-	if (showvers) {
+	if (showvers)
 		show_version(argv[0]);
-	}
 
 	char const * file;
-	while ((file = poptGetArg(con)) != 0) {
+	while ((file = poptGetArg(con)) != 0)
 		additional_params.push_back(file);
-	}
 
-	for (size_t i = 0 ; i < options_list.size() ; ++i) {
-		options_list[i]->post_process();
-	}
+	for (size_t i = 0 ; i < options_list().size() ; ++i)
+		options_list()[i]->post_process();
 
 	return con;
 }
@@ -157,7 +163,7 @@ public:
  */
 template <> class option_imp<string> : public option_base {
 public:
-	option_imp(string & value,char const * option_name,
+	option_imp(string & value, char const * option_name,
 	           char short_name, char const * help_str,
 	           char const * arg_help_str);
 
@@ -248,9 +254,9 @@ option_base::option_base(char const * name, char short_name,
 	poptOption const opt = { name, short_name, popt_flags,
 	                         data, 0, help, arg_help };
 
-	popt_options.push_back(opt);
+	popt_options().push_back(opt);
 
-	options_list.push_back(this);
+	options_list().push_back(this);
 }
 
 
