@@ -9,10 +9,13 @@
  * @author Philippe Elie
  */
 
+#include <cstdlib>
+
 #include <vector>
 #include <list>
 #include <iterator>
 #include <iostream>
+#include <cstdlib>
 
 #include "profile_spec.h"
 #include "arrange_profiles.h"
@@ -26,7 +29,6 @@ using namespace std;
 profile_classes classes;
 
 namespace options {
-	string archive_path;
 	demangle_type demangle = dmt_normal;
 	string output_dir;
 	vector<string> search_dirs;
@@ -51,7 +53,7 @@ string demangle_option = "normal";
 vector<string> mergespec;
 
 popt::option options_array[] = {
-	popt::option(demangle_option, "demangle", '\0',
+	popt::option(demangle_option, "demangle", 'D',
 		     "demangle GNU C++ symbol names (default normal)",
 	             "none|normal|smart"),
 	popt::option(options::output_dir, "output-dir", 'o',
@@ -69,22 +71,30 @@ popt::option options_array[] = {
 	popt::option(exclude_symbols, "exclude-symbols", 'e',
 		     "exclude these comma separated symbols", "symbols"),
 	popt::option(options::objdump_params, "objdump-params", '\0',
-		     "additionnal params to pass to objdump", "parameters"),
+		     "additional params to pass to objdump", "parameters"),
 	popt::option(options::exclude_dependent, "exclude-dependent", 'x',
 		     "exclude libs, kernel, and module samples for applications"),
 	popt::option(mergespec, "merge", 'm',
 		     "comma separated list", "cpu,tid,tgid,unitmask,all"),
 	popt::option(options::source, "source", 's', "output source"),
 	popt::option(options::assembly, "assembly", 'a', "output assembly"),
+	popt::option(options::threshold_opt, "threshold", 't',
+		     "minimum percentage needed to produce output",
+		     "percent"),
 };
 
 }  // anonymous namespace
 
 
-void handle_options(vector<string> const & non_options)
+void handle_options(options::spec const & spec)
 {
 	using namespace options;
 
+	if (spec.first.size()) {
+		cerr << "differential profiles not allowed" << endl;
+		exit(EXIT_FAILURE);
+	}
+
 	if (!assembly && !source) {
 		cerr <<	"you must specify at least --source or --assembly\n";
 		exit(EXIT_FAILURE);
@@ -102,17 +112,22 @@ void handle_options(vector<string> const & non_options)
 		exit(EXIT_FAILURE);
 	}
 
+	if (assembly && !output_dir.empty()) {
+		cerr << "--output-dir is meaningless with --assembly" << endl;
+		exit(EXIT_FAILURE);
+	}
+
 	options::symbol_filter = string_filter(include_symbols, exclude_symbols);
 
 	options::file_filter = path_filter(include_file, exclude_file);
 
-	profile_spec const spec =
-		profile_spec::create(non_options, options::extra_found_images);
+	profile_spec const pspec =
+		profile_spec::create(spec.common, options::image_path,
+				     options::root_path);
 
-	list<string> sample_files = spec.generate_file_list(exclude_dependent, true);
+	list<string> sample_files = pspec.generate_file_list(exclude_dependent, true);
 
-	archive_path = spec.get_archive_path();
-	cverb << vsfile << "Archive: " << archive_path << endl;
+	cverb << vsfile << "Archive: " << pspec.get_archive_path() << endl;
 
 	cverb << vsfile << "Matched sample files: " << sample_files.size()
 	      << endl;
@@ -125,7 +140,8 @@ void handle_options(vector<string> const & non_options)
 	// or assembly point of view the result will be merged anyway
 	merge_by = handle_merge_option(mergespec, false, exclude_dependent);
 
-	classes = arrange_profiles(sample_files, merge_by);
+	classes = arrange_profiles(sample_files, merge_by,
+				   pspec.extra_found_images);
 
 	cverb << vsfile << "profile_classes:\n" << classes << endl;
 
