@@ -27,10 +27,10 @@ extern inverted_profile image_profile;
 
 /**
  * handle_options - process command line
- * @param non_options vector of non options string
+ * @param spec  profile specification
  *
- * Process the arguments, fatally complaining on error.
+ * Process the spec, fatally complaining on error.
  */
-void handle_options(std::vector<std::string> const & non_options);
+void handle_options(options::spec const & spec);
 
 #endif // OPGPROF_OPTIONS_H
